# Numerics In Abstract Spaces

[![PyPI](https://img.shields.io/pypi/v/nias.svg)](https://pypi.python.org/pypi/nias)
[![Documentation Status](https://readthedocs.org/projects/nias/badge/?version=latest)](https://nias.readthedocs.io/en/latest/?badge=latest)
[![Tests](https://github.com/nias-project/nias/actions/workflows/tests.yml/badge.svg)](https://github.com/nias-project/nias/actions/workflows/tests.yml)
